.. IDS-skill documentation master file, created by
   sphinx-quickstart on Thu Oct 15 16:36:40 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

******
VIRTUE
******

.. include:: overview.rst

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   :hidden:

   overview
   packaging/index
   api/index
   conda


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
